==> assertj-build-3.25.3.tar.gz: assertj-assertj-build-3.25.3/assertj-core/src/test/java/org/assertj/core/internal/floats/Floats_assertIsPositive_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2024 the original author or authors.
 */
package org.assertj.core.internal.floats;

import static java.lang.String.format;
import static org.assertj.core.api.Assertions.assertThatExceptionOfType;
import static org.assertj.core.test.TestData.someInfo;

import org.assertj.core.api.AssertionInfo;
import org.assertj.core.internal.Floats;
import org.assertj.core.internal.FloatsBaseTest;
import org.junit.jupiter.api.Test;

/**
 * Tests for <code>{@link Floats#assertIsPositive(AssertionInfo, Float)}</code>.
 *
 * @author Alex Ruiz
 * @author Joel Costigliola
 */
class Floats_assertIsPositive_Test extends FloatsBaseTest {

  @Test
  void should_succeed_since_actual_is_positive() {
    floats.assertIsPositive(someInfo(), 6.0f);
  }

  @Test
  void should_fail_since_actual_is_not_positive() {
    assertThatExceptionOfType(AssertionError.class).isThrownBy(() -> floats.assertIsPositive(someInfo(), -6.0f))
                                                   .withMessage(format("%nExpecting actual:%n  -6.0f%nto be greater than:%n  0.0f%n"));
  }

  @Test
  void should_succeed_since_actual_is_positive_according_to_absolute_value_comparison_strategy() {
    floatsWithAbsValueComparisonStrategy.assertIsPositive(someInfo(), (float) 6);
  }

  @Test
  void should_succeed_since_actual_is_positive_according_to_absolute_value_comparison_strategy2() {
    floatsWithAbsValueComparisonStrategy.assertIsPositive(someInfo(), -6.0f);
  }

}

==> assertj-build-3.27.6.tar.gz: assertj-assertj-build-3.27.6/assertj-core/src/test/java/org/assertj/core/internal/floats/Floats_assertIsPositive_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2025 the original author or authors.
 */
package org.assertj.core.internal.floats;

import static java.lang.String.format;
import static org.assertj.core.api.Assertions.assertThatExceptionOfType;
import static org.assertj.core.testkit.TestData.someInfo;

import org.assertj.core.api.AssertionInfo;
import org.assertj.core.internal.Floats;
import org.assertj.core.internal.FloatsBaseTest;
import org.junit.jupiter.api.Test;

/**
 * Tests for <code>{@link Floats#assertIsPositive(AssertionInfo, Float)}</code>.
 *
 * @author Alex Ruiz
 * @author Joel Costigliola
 */
class Floats_assertIsPositive_Test extends FloatsBaseTest {

  @Test
  void should_succeed_since_actual_is_positive() {
    floats.assertIsPositive(someInfo(), 6.0f);
  }

  @Test
  void should_fail_since_actual_is_not_positive() {
    assertThatExceptionOfType(AssertionError.class).isThrownBy(() -> floats.assertIsPositive(someInfo(), -6.0f))
                                                   .withMessage(format("%nExpecting actual:%n  -6.0f%nto be greater than:%n  0.0f%n"));
  }

  @Test
  void should_succeed_since_actual_is_positive_according_to_absolute_value_comparison_strategy() {
    floatsWithAbsValueComparisonStrategy.assertIsPositive(someInfo(), (float) 6);
  }

  @Test
  void should_succeed_since_actual_is_positive_according_to_absolute_value_comparison_strategy2() {
    floatsWithAbsValueComparisonStrategy.assertIsPositive(someInfo(), -6.0f);
  }

}
